﻿using System.Collections.ObjectModel;

using Prism.Events;
using Prism.Mvvm;

using TestLibrary;

namespace TestModule2.ViewModels
{
    /// <summary>
    /// 메시지 리스트 뷰 모델
    /// </summary>
    public class MessageListViewModel : BindableBase
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Field
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region Field

        /// <summary>
        /// 이벤트 수집기
        /// </summary>
        private IEventAggregator eventAggregator;

        /// <summary>
        /// 메시지 컬렉션
        /// </summary>
        private ObservableCollection<string> messageCollection;

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Property
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 메시지 컬렉션 - MessageCollection

        /// <summary>
        /// 메시지 컬렉션
        /// </summary>
        public ObservableCollection<string> MessageCollection
        {
            get
            {
                return this.messageCollection;
            }
            set
            {
                SetProperty(ref this.messageCollection, value);
            }
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MessageListViewModel(eventAggregator)

        /// <summary>
        /// 생성자
        /// </summary>
        /// <param name="eventAggregator">이벤트 수집기</param>
        public MessageListViewModel(IEventAggregator eventAggregator)
        {
            this.eventAggregator = eventAggregator;

            MessageCollection = new ObservableCollection<string>();

            this.eventAggregator.GetEvent<MessageSentEvent>().Subscribe(MessageReceived);
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region 메시지 수신시 처리하기 - MessageReceived(message)

        /// <summary>
        /// 메시지 수신시 처리하기
        /// </summary>
        /// <param name="message">메시지</param>
        private void MessageReceived(string message)
        {
            MessageCollection.Add(message);
        }

        #endregion
    }
}